@@ -15,11 +15,31 @@
 #include <QFileDialog>
 #include <QIcon>
 
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
+
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
+
 int main(int argc, char *argv[])
 {
+#if HAVE_KICONTHEME
+    KIconTheme::initTheme();
+#endif
     QApplication app(argc, argv);
     app.setDesktopFileName(QStringLiteral("org.kde.mboximporter"));
     KCrash::initialize();
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif
+#endif
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("mboximporter"));
 
     KAboutData aboutData(QStringLiteral("mboximporter"),
@@ -28,7 +48,7 @@ int main(int argc, char *argv[])
                          i18n("MBox Import Tool"),
                          KAboutLicense::GPL_V2,
                          i18n("Copyright © 2013-%1 MBoxImporter authors", QStringLiteral("2024")));
-    aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
     aboutData.setProductName(QByteArray("mboximporter"));
